@@ -23,7 +23,7 @@ use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 
 @EXPORT_OK = ( @{$EXPORT_TAGS{'all'}} );
 
-$VERSION = '0.23';
+$VERSION = '0.25';
 
 bootstrap UUID $VERSION;
 
@@ -183,6 +183,12 @@ Creates a new string format UUID and returns it in a more Perlish way.
 Functionally the equivalent of calling B<generate()> and then B<unparse()>, but
 throwing away the intermediate binary UUID.
 
+=head1 UUID LIBRARY
+
+Note that on some systems external packages will need to be installed
+first. Notably, uuid-dev or uuid-devel on Debian and RedHat Linux,
+respectively, and their derivatives.
+
 =head1 EXPORTS
 
 All functions may be imported in the usual manner, either individually
@@ -194,7 +200,7 @@ Need more tests and sanity checks.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Rick Myers.
+This software is Copyright (c) 2014-2016 by Rick Myers.
 
 This is free software, licensed under:
 
@@ -218,6 +224,12 @@ Authors and/or previous maintainers:
 
   Peter J. Braam <braam@mountainviewdata.com>
 
+=head1 CONTRIBUTORS
+
+David E. Wheeler <dwheeler@cpan.org>
+
+William Faulk <wfaulk@gmail.com>
+
 =head1 SEE ALSO
 
 B<uuid(3)>, B<uuid_clear(3)>, B<uuid_compare(3)>, B<uuid_copy(3)>,
